@@ -19,6 +19,6 @@
 
 LIBDIR = r'/usr/local/lib'
 DATADIR = r'/usr/local/share'
-BUILDDIR = r'/pobj/gst-devtools-1.26.3/build-mips64'
-SRCDIR = r'/pobj/gst-devtools-1.26.3/gst-devtools-1.26.3'
+BUILDDIR = r'/usr/obj/ports/gst-devtools-1.26.4/build-powerpc64'
+SRCDIR = r'/usr/obj/ports/gst-devtools-1.26.4/gst-devtools-1.26.4'
 GST_VALIDATE_TESTSUITE_VERSION = '1.26'
